%%Indicizzazione vettori

v = [1 3 5 7 9] 
elem = v(2)		% accesso a un elemento
w = v' 		% trasposta
a = v(1:3)  		% accesso a un blocco
b = v(4:end) 		% accesso a un blocco
c = v(1:2:end) 	% blocco non contiguo
d = v(end:-2:1)	% step negativo
e = v([1 4 5]) 	%uso un vettore per indicizzare un altro vettore

%%Indicizzazione di matrici

A = [1 2 3; 4 5 6; 7 8 9];
elem = A(2, 3)          % accesso a un elemento
W = A'                  % trasposta
c3 = A(:,3)             % accesso alla 3 colonna
r2 = A(2, :)            % accesso alla 2 riga
B = A(1:2,:)            % blocco delle prime 2 righe
B2 = A(2:3,2:3)         % blocco 2 x2
B3 = A(2:3,end:-2:1)    % step negativo
E = A([2 3], [1 2])  	% E = A([a b], [c d]):seleziona gli elementi: A(a,c),A(a,d),A(b,c),A(b,d)
D = logical([1 0 0; 0 0 1; 0 0 0])
Atrue = A(D)           % seleziona gli elem =1 di D
V = A(:)                % trasforma la matrice in colonna, accodando le colonne di A
s = sum(A(:))           % equivale a sum(sum(A));

% Lettura di un'immagine, visualizzazione e salvataggio

% Inizializzazione
clc;
clear all;
close all;

[imgName, path] = picimage('./', 0, 'pick up 1 gray scale image');
img = imread([path imgName]);

figure;
imshow(img);
title(['Immagine ' imgName]);
%pause;

%oppure
figure;
imshow([path imgName]);
img = getimage;

% Salvataggio di un'immagine
imwrite(img,[path 'prova_imwrite.bmp'], 'bmp');
%pause;

%% manipolazione dell'img

subplot(2,2,1);
imshow(img);
title('Original image');

img_flippedV = img(end:-1:1, :); %Immagine capovolta verticalmente:
subplot(2,2,2);
imshow(img_flippedV);
title('Vertical flip');

img_flippedO = img(:, end:-1:1); %Immagine capovolta orizzontalmente:
subplot(2,2,3);
imshow(img_flippedO);
title('Horizontal flip');

Q = img( round(end/2):end,  round(end/2):end); % estrazione del quarto quadrante
subplot(2,2,4);
imshow(Q);
title('Fourth quadrant');

%%Conversioni tra classi

f = [-0.5 	0.5	   
      0.75	1.5]
g = im2uint8(f)         %effettua le scalature necessarie per riconoscere B come unimg valida di tipo uint8


h = uint8([25 50; 128 200])
g = im2double(h)        %loutput  scalato nel range [0 1] (dividendo i valori per 255)

h = double([345.5  2341
           -256.9 0])
g = im2double(h)        %loutput  invariato
g_scaled =mat2gray(g)   %per avere l'output scalato nel range [0 1]
gb = im2bw(g_scaled)
gb2 = g_scaled > 0.5    %le ultime 2 istruzioni sono equivalenti


%% Conversioni tra tipi di rappresentazione dei dati
clc;
clear all;
close all;
[imgName, path] = picimage('./', 0, 'pick up 1 gray scale image');
img = imread([path imgName]);
figure; imshow(img);colorbar; title('Immagine Grayscale uint8 [0,255]');

% grayscale uint8 --> grayscale uint16
img_uint16 = im2uint16(img);
figure; imshow(img_uint16); colorbar; title('Conversione Grayscale uint8 --> uint16 [0,65535]');

% grayscale uint8 --> grayscale double
img_double = im2double(img);
figure; imshow(img_double); colorbar; title('Conversione Grayscale uint8 --> double [0,1]');

% im2uint8, im2uint16, im2int16, im2single,
% or im2double



%% Aritmetica tra immagini (overflow/underflow, arrotondamenti di razionali)
close all;

[imgNames, path] = picimage('./', 1, 'pickup 2 gray scale images');
img_gray1 = imread([path imgNames{1}]);
img_gray2 = imread([path imgNames{2}]);

figure; imshow(img_gray1); title('Img uint8 [0,255]');

img_gray2 = imresize(img_gray2, [size(img_gray1,1) size(img_gray1,2)]);
figure; imshow(img_gray2); title('Img 2 Grayscale uint8 [0,255] ridimensionata come la precedente');

%addition
c = 100;
img_gray_add = img_gray1 + c;
subplot(2,1,1);
imshow(img_gray1);
subplot(2,1,2);
imshow(img_gray_add); 
title('Aumento della brightness');
%pause;

figure;
img_gray_add_f =  img_gray1 + img_gray2 ;
subplot(1,2,1);
imshow(img_gray_add_f); title('Addition ');

%subtraction
img_gray_sub  = img_gray1 - img_gray2;
subplot(1,2,2);
imshow(img_gray_sub); title('Subtraction');

disp('PROVARE CON imadd e imsubtract cosa cambia???');
pause;

close all;
clear all;

[imgNames, path] = picimage('..\..\..\img', 1, 'pickup 1 gray scale image and its map');
img_gray1 = imread([path imgNames{1}]);
img_mask = imread([path imgNames{2}]);

figure;
subplot(1,3,1);
imshow(img_gray1, []); title('original Image');

subplot(1,3,2);
imshow(img_mask, []); title('Mask');

%multiplication

img_gray_mult = img_gray1.* uint8(img_mask>128);
subplot(1,3,3); imshow(img_gray_mult, []); title('Multiplication');
% pause;


%% Ridimensionamento di un'immagine --> TEORIA METODI INTERPOLAZIONE
close all;

figure; imshow(img_gray1); title('Immagine originale (Grayscale)');

img_gray_reduced = imresize(img_gray1, 0.25);
subplot(3,2,1); imshow(img_gray_reduced); title('Ridotta di 1/4');

img_gray_enlarged = imresize(img_gray_reduced, 4, 'nearest');
subplot(3,2,2); imshow(img_gray_enlarged); title('Ridotta (1/4) ed Allargata (4) con interpolazione Nearest-Neighbor');

img_gray_enlarged = imresize(img_gray_reduced, 4, 'bilinear');
subplot(3,2,3); imshow(img_gray_enlarged); title('Ridotta (1/4) ed Allargata (4) con interpolazione Bilineare');

img_gray_enlarged = imresize(img_gray_reduced, 4, 'bicubic'); % default
subplot(3,2,4); imshow(img_gray_enlarged); title('Ridotta (1/4) ed Allargata (4) con interpolazione Bicubica');

img_gray_resized = imresize(img_gray1, [200 500]);
subplot(3,2,5); imshow(img_gray_resized); title('Ridimensionata con nuove proporzioni con interpolazione Nearest-Neighbor (default di imresize)');

img_gray_resized = imresize(img_gray1, [200 500], 'bicubic' );
subplot(3,2,6); imshow(img_gray_resized); title('Ridimensionata con nuove proporzioni con interpolazione Bicubica');
%pause;


%% Rotazione di un'immagine
close all;

img_gray_rotated = imrotate(img_gray1, 35, 'crop'); 
subplot(2,2,1); imshow(img_gray_rotated);title('Ruotata di 35 con interpolazione Nearest-Neighbor (stesse dimensioni in output)');

img_gray_rotated = imrotate(img_gray1, 35); %default = nearest neighbor
subplot(2,2,2); imshow(img_gray_rotated); title('Ruotata di 35 con interpolazione Nearest-Neighbor');

img_gray_rotated = imrotate(img_gray1, 35, 'bilinear'); 
subplot(2,2,3); imshow(img_gray_rotated); title('Ruotata di 35 con interpolazione Bilineare');

img_gray_rotated = imrotate(img_gray1, 35, 'bicubic'); 
subplot(2,2,4); imshow(img_gray_rotated); title('Ruotata di 35 con interpolazione Bicubica');
%pause;
