function [filename, path] = picfile( type, title, startpath )
%PICFILE Allow to select a file from the fylesystem
%
% [filename, path] = picfile( type, title, startpath )
%
%  This function allow to select a file from the filesystem ina fine and
% pleasant manner.
% 
%  Examples:
%  =========
% 
% Get a filename
% >> picfile
%  
% Get a filename of a specified type:
% >> picfile({'*.gif'; '*.jpg'; '*.bmp'})
%
% Get a filename with a specified title and filetype:
% >> picfile({'*.gif'; '*.jpg'; '*.bmp'}, 'Title')
%
% Get a filename and its directory name:
% >> [filename, pathname] = picfile()

% Check arguments
if( nargin<3 )
    startpath = pwd;
end
if( nargin<2 )
    title = 'Select a file';
end
if( nargin<1 )
    type = {'*.*', 'All files (*.*)'};
end

% Save current position and chdir
oldpwd = pwd;
if( isdir(startpath) )
    cd(startpath);
end

% Obtain filename
if( nargout==2 )
    [filename, path] = uigetfile(type, title);
else
    filename = uigetfile(type, title);
end

% returning in the old path
cd(oldpwd);
