function [imagename, path] = picimage(startpath, allowMultiple, Wtitle)
%PICIMAGE Allow to pic an image filename
%
% [imagename, path] = picimage( startpath, allowMultiple )
%
%  Allow to pic an image filename (or multiple ones if the second argument
% is true).
%  All the two returning arguments must be read.
%
%  Params:
%
% startpath:        Starting path for the images search (def=.)
% allowMultiple:    Permit a multiple selection? (ded=false)
%
% imagename:         The imagenames (if this is the only output param this
%                   contains the complete absolute path, otherwise contains
%                   only the filename)
% path:              The path of the directory
% 
%  Examples:
%  =========
% 
% Pic an image filename and path:
% >> [filename, path] = picimage();
%
% Pic multiple images filename and path (filenames in a cell):
% >> [filenames, path] = picimage('/home/ilgab/images/samples', true);

% Prepare arguments

if( nargin<2 )
    allowMultiple = false;
end
if( nargin<1 )
    startpath = pwd;
end

if nargin == 3
    title = Wtitle;
else
    if( allowMultiple )
        title = 'Pic up a group of image files';
    else
        title = 'Pic up an image file';
    end
end
% Prepare other infos
type = {'*.gif;*.GIF;*.jpg;*.JPG;*.jpeg;*.tif;*.TIF;*.tiff;*.bmp;*.BMP;*.png;*.PNG',...
            'All image files (*.gif;*.jpg;*.jpeg;*.tif;*.tiff;*.bmp;*.png)';
        '*.gif;*.GIF', 'Gif files (*.gif)';
        '*.jpg;*.JPG;*.jpeg', 'JPEG files (*.jpg;*.jpeg)';
        '*.tif;L*.TIF;*.tiff', 'Tiff files (*.tif;*.tiff)';
        '*.bmp;*.BMP', 'BMP files (*.bmp)';
        '*.png;*.PNG', 'PING files (*.png)';
        '*.*', 'All files'};

% Prepare execution
oldpwd = pwd;
cd(startpath);
    
% Obtain the filename
if( allowMultiple )
    % Can't work with Matlab releases <14
    [imagename, path] = uigetfile(type, title, 'MultiSelect', 'on');
else
    [imagename, path] = uigetfile(type, title);
end

% Check number of arguments
if( nargout<=1 )
    if( iscell(imagename) )
        for i=1:size(imagename,2)
            imagename{i} = [path imagename{i}];
        end
    else
        imagename = [path imagename];
    end
end

% Returning in old path
cd(oldpwd);
